/*
   orxonox - the future of 3D-vertical-scrollers

   Copyright (C) 2004 orx

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

### File Specific:
   main-programmer: hdavid, amaechler
*/

#include "lightening_effect.h"

#include "state.h"
#include "util/loading/load_param.h"
#include "util/loading/factory.h"
#include "effects/billboard.h"

#include "glincl.h"
#include "parser/tinyxml/tinyxml.h"

using namespace std;

CREATE_FACTORY(LighteningEffect, CL_LIGHTENING_EFFECT);

LighteningEffect::LighteningEffect(const TiXmlElement* root)
{
	this->setClassID(CL_LIGHTENING_EFFECT, "LighteningEffect");
  
	this->init();

	if (root != NULL)
		this->loadParams(root);

	this->activate();
}

LighteningEffect::~LighteningEffect()
{
	this->deactivate();
}

void LighteningEffect::loadParams(const TiXmlElement* root)
{
	WeatherEffect::loadParams(root);
}


bool LighteningEffect::init()
{
  this->time = 0.0;
  this->flashFrequency = 0.6f;
  this->flashConstTime = 0.07f;

  //this->material = new Material();
  //this->material->setDiffuseMap("maps/lightning_bolt.png");
  //this->offset = Vector(-1440.00, 100.00, 280.00);

//  this->billboard->setAbsCoor(50, 0, 0);
  this->width = 20.0f;
  this->height = 5.0f;
  this->bNewCoordinate = false;

  this->seedX = 20.f;
  this->seedZ = 50.0f;
  this->seedTime = 4.0f;

  this->billboard = new Billboard(NULL);
  this->billboard->setTexture("maps/lightning_bolt.png");
  this->billboard->setSize(this->width, this->height);
  this->billboard->setAbsCoor(50, 0, 0);
  this->billboard->setVisibiliy(false);
  //this->billboard->setAbsCoor(50, 0, 0);
  //this->billboard->setVisibiliy(true);

/*
  this->soundSource = NULL;
  this->thunderBuffer = NULL;

  this->soundSource.setSourceNode(this);

  //load sound
  if (this->thunderBuffer != NULL)
    ResourceManager::getInstance()->unload(this->thunderBuffer);
  this->thunderBuffer = (OrxSound::SoundBuffer*)ResourceManager::getInstance()->load("sound/thunder.wav", WAV);*/
}


bool LighteningEffect::activate()
{
	PRINTF(0)( "Activating LighteningEffect\n" );

}


bool LighteningEffect::deactivate()
{
	PRINTF(0)("Deactivating LighteningEffect\n");
}

void LighteningEffect::tick (float dt)
{
  this->time += dt;

  if( this->time > this->flashFrequency)
  {
    this->billboard->setVisibiliy(true);
    this->time = 0.0f;
    //this->soundSource.play(this->thunderBuffer);
  }
  else if( this->billboard->isVisible() && this->time > this->flashConstTime)
  {
    this->billboard->setVisibiliy(false);
    this->time = 0.0f;
    this->bNewCoordinate = true;
  }

  if( this->bNewCoordinate)
  {
    //this->flashFrequency = this->seedTime * (float)rand()/(float)RAND_MAX + 0.1;
    //this->billboard>setAbsCoor( - 800.0f - this->seedX * (float)rand()/(float)RAND_MAX, 250.00, -200.0f + this->seedZ * (float)rand()/(float)RAND_MAX);
    this->bNewCoordinate = false;
  }
}
